@@ -27,8 +27,9 @@
 #include <string.h>
 #include <sys/stat.h>
 
+#include <glib/gi18n-lib.h>
+
 #include <libedataserver/e-data-server-util.h>
-#include <camel/camel-i18n.h>
 
 #include "camel-exchange-folder.h"
 #include "camel-exchange-search.h"
@@ -1003,14 +1004,14 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 	guint32 folder_flags;
 	CamelMessageInfo *info;
 	CamelExchangeMessageInfo *einfo;
-	int i, len;
+	int i, len = 0;
 
 	short_name = strrchr (name, '/');
 	if (!short_name++)
 		short_name = name;
 	camel_folder_construct (folder, parent, name, short_name);
 
-	if (e_util_mkdir_hier (folder_dir, S_IRWXU) != 0) {
+	if (g_mkdir_with_parents (folder_dir, S_IRWXU) != 0) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Could not create directory %s: %s"),
 				      folder_dir, g_strerror (errno));
@@ -1102,6 +1103,9 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 		if (!ok)
 			return FALSE;
 
+		if (len)
+			return TRUE;
+
 		if (folder_flags & CAMEL_STUB_FOLDER_FILTER)
 			folder->folder_flags |= CAMEL_FOLDER_FILTER_RECENT;
 		if (folder_flags & CAMEL_STUB_FOLDER_FILTER_JUNK)
